Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
dGraphMake.ml1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31(**************************************************************************) (* *) (* This file is part of OcamlGraph. *) (* *) (* Copyright (C) 2009-2010 *) (* CEA (Commissariat à l'Énergie Atomique) *) (* *) (* you can redistribute it and/or modify it under the terms of the GNU *) (* Lesser General Public License as published by the Free Software *) (* Foundation, version 2.1, with a linking exception. *) (* *) (* It is distributed in the hope that it will be useful, *) (* but WITHOUT ANY WARRANTY; without even the implied warranty of *) (* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the *) (* GNU Lesser General Public License for more details. *) (* *) (* See the file ../LICENSE for more details. *) (* *) (* Authors: *) (* - Julien Signoles (Julien.Signoles@cea.fr) *) (* - Jean-Denis Koeck (jdkoeck@gmail.com) *) (* - Benoit Bataille (benoit.bataille@gmail.com) *) (* *) (**************************************************************************) open Graph open XDot open Printf exception DotError of string